@@ -11,7 +11,7 @@ from typing import Any, List
 from rich.progress import track
 from rich.table import Table
 
-from . import __version__, csv_edem_batch, csv_edem_controller, csv_input
+from . import __version__, csv_edem_batch, csv_edem_controller, csv_input, utils
 from .rich_console import console
 
 logger = logging.getLogger("csv_edem")
@@ -19,6 +19,82 @@ logger = logging.getLogger("csv_edem")
 INPUT_TXT_DEFAULT = "input_csv_edem.txt"
 
 
+def gen_input_txt(gen_dir: Path, input_file: str, info: bool = False) -> None:
+
+    console.print(f'Generating files from "{str(gen_dir)}"')
+
+    csv_files_in_curr_dir = [f for f in gen_dir.iterdir() if utils.isValidCSV(str(f))]
+    i = 1
+    with open(input_file, "w") as outf:
+        for csv in track(
+            csv_files_in_curr_dir, description="Getting files...", transient=True
+        ):
+            time.sleep(0.1)
+            outf.write(str(csv))
+            outf.write(os.linesep)
+
+    console.print(f"Found [bold blue]{len(csv_files_in_curr_dir)}[/] files:")
+    for csv in csv_files_in_curr_dir:
+        if not info:
+            f = Path(os.curdir).resolve() / csv
+            console.print(f'  {i:02d} - "{f}"')
+            i += 1
+
+    logger.info('"{}" generated'.format(input_file))
+
+
+def batch_input_txt(
+    input_file: str, args: argparse.Namespace, info: bool = False
+) -> None:
+
+    # check if batch file exists
+    if not os.path.isfile(input_file):
+        logger.warning('Batch mode input file "{}" does not exist'.format(input_file))
+        return
+
+    batch_ctrller = csv_edem_batch.CSV_Edem_Batch(input_file, args)
+    batch_ctrller.executeBatch(progress_bar=console if not info else None)
+    excel_file: str = "batch_EDEM_files"
+    batch_ctrller.saveToExcel(excel_file)
+
+    # show rich table
+    headers = batch_ctrller.getHeaders()
+    data = batch_ctrller.getData()
+    table = Table()
+
+    mean_row = ["" for _ in range(len(headers))]
+    mean_row[0] = "Mean"
+    mean_row[1] = f"{batch_ctrller.getMeanOfNormalCollisions():.5f}"
+
+    if batch_ctrller.isExportingLog():
+        mean_row[2] = f"{ batch_ctrller.getMeanOfLogCollisions():.5f}"
+        mean_row[3] = f"{batch_ctrller.getMeanOfNormalForces():.5f}"
+        mean_row[4] = f"{batch_ctrller.getMeanOfLogForces():.5f}"
+    else:
+        mean_row[2] = f"{batch_ctrller.getMeanOfNormalForces():.5f}"
+
+    console.print(f"[bold blue]{Path(data[0,0]).parent.resolve()}")
+
+    index = 0
+    for header in headers:
+        if index == 0:
+            table.add_column(header, justify="left")
+        else:
+            table.add_column(header, justify="right")
+        mean_row[index] = f"[bold red]{mean_row[index]}[/]"
+        index += 1
+
+    for i in range(len(data)):
+        data[i, 0] = str(Path(data[i, 0]).name)
+        if i == len(data) - 1:
+            table.add_row(*data[i], end_section=True)
+        else:
+            table.add_row(*data[i])
+
+    table.add_row(*mean_row)
+    console.print(table)
+
+
 def main(_args: List[str] = None) -> Any:
 
     default_skip_rows: int = 25
@@ -96,6 +172,14 @@ def main(_args: List[str] = None) -> Any:
         help=f'treat batch files. BATCH is a input file containing the CSV files in order to be processed. Default value is "{INPUT_TXT_DEFAULT}"',
     )
 
+    parser.add_argument(
+        "-B",
+        dest="B",
+        nargs="?",
+        default=".",
+        help=f"same as -g followed by -b",
+    )
+
     parser.add_argument(
         "-l",
         "--log",
@@ -164,100 +248,34 @@ def main(_args: List[str] = None) -> Any:
 
         return 0
 
-    if ("-g" in sys.argv) or ("--gen_batch" in sys.argv):
-        input_file: str = INPUT_TXT_DEFAULT
-        gen_dir = (
-            Path(args.gen_batch).resolve()
-            if args.gen_batch is not None
-            else Path(os.curdir).resolve()
-        )
+    if "-B" in sys.argv:
+        logger.info(f"-B called with args {args.B}")
+        bdir: Path = Path(".").resolve() if (args.B is None) else Path(args.B).resolve()
 
+        gen_input_txt(bdir, INPUT_TXT_DEFAULT, info=info)
+        console.rule()
+        batch_input_txt(INPUT_TXT_DEFAULT, args, info=info)
+
+        logger.info(f"Removing {INPUT_TXT_DEFAULT}")
+        os.remove(INPUT_TXT_DEFAULT)
+
+        return 0
+
+    elif ("-g" in sys.argv) or ("--gen_batch" in sys.argv):
         logger.info(
-            'Generate batch file mode called with arg "{}"'.format(str(gen_dir))
+            'Generate batch file mode called with arg "{}"'.format(args.gen_batch)
         )
-
-        console.print(f'Generating files from "{gen_dir}"')
-
-        f: Path
-        csv_files_in_curr_dir = [
-            Path(f).resolve() for f in gen_dir.iterdir() if f.suffix.lower() == ".csv"
-        ]
-
-        if len(csv_files_in_curr_dir) < 1:
-            console.print(f"[red bold]No CSV files found!")
-            return
-
-        i = 1
-        with open(input_file, "w") as outf:
-            for csv in track(
-                csv_files_in_curr_dir, description="Getting files...", transient=True
-            ):
-                time.sleep(0.1)
-                outf.write(str(csv))
-                outf.write(os.linesep)
-
-        console.print(f"Found [bold blue]{len(csv_files_in_curr_dir)}[/] files:")
-        for csv in csv_files_in_curr_dir:
-            if not info:
-                f = gen_dir / csv
-                console.print(f'  {i:02d} - "{f}"')
-                i += 1
-
-        logger.info('"{}" generated'.format(input_file))
+        gen_dir: Path = (
+            Path(".").resolve()
+            if (args.gen_batch is None)
+            else Path(args.gen_batch).resolve()
+        )
+        gen_input_txt(gen_dir, INPUT_TXT_DEFAULT, info=info)
 
     elif ("-b" in sys.argv) or ("--batch" in sys.argv):
         input_file = INPUT_TXT_DEFAULT if (args.batch is None) else args.batch
         logger.info('Batch mode called with arg "{}"'.format(input_file))
-
-        # check if batch file exists
-        if not os.path.isfile(input_file):
-            logger.warning(
-                'Batch mode input file "{}" does not exist'.format(input_file)
-            )
-            return 1
-
-        batch_ctrller = csv_edem_batch.CSV_Edem_Batch(input_file, args)
-        batch_ctrller.executeBatch(progress_bar=console if not info else None)
-        excel_file: str = "batch_EDEM_files"
-        batch_ctrller.saveToExcel(excel_file)
-
-        # show rich table
-        headers = batch_ctrller.getHeaders()
-        data = batch_ctrller.getData()
-        table = Table()
-
-        mean_row = ["" for _ in range(len(headers))]
-        mean_row[0] = "Mean"
-        mean_row[1] = f"{batch_ctrller.getMeanOfNormalCollisions():.5f}"
-
-        if batch_ctrller.isExportingLog():
-            mean_row[2] = f"{ batch_ctrller.getMeanOfLogCollisions():.5f}"
-            mean_row[3] = f"{batch_ctrller.getMeanOfNormalForces():.5f}"
-            mean_row[4] = f"{batch_ctrller.getMeanOfLogForces():.5f}"
-        else:
-            mean_row[2] = f"{batch_ctrller.getMeanOfNormalForces():.5f}"
-
-        index = 0
-        for header in headers:
-            if index == 0:
-                table.add_column(header, justify="left")
-            else:
-                table.add_column(header, justify="right")
-            mean_row[index] = f"[bold red]{mean_row[index]}[/]"
-            index += 1
-
-        console.print(f'[blue bold]Directory:[/] "{Path(data[0,0]).parent.resolve()}"')
-
-        for i in range(len(data)):
-            # get only file basename
-            data[i, 0] = Path(data[i, 0]).name
-            if i == len(data) - 1:
-                table.add_row(*data[i], end_section=True)
-            else:
-                table.add_row(*data[i])
-
-        table.add_row(*mean_row)
-        console.print(table)
+        batch_input_txt(input_file, args, info)
 
     elif ("-s" in sys.argv) or ("--single-file" in sys.argv):
         if not info:
